# Integrations & Interfaces

The Space Robotics Bench has a modular design that supports integrations & interfaces with external frameworks and tools. This enables researchers and developers to leverage the high-fidelity environments while using their preferred toolchains for research, development, and validation.

At the moment, SRB natively supports the following categories of integrations/interfaces:

- [**ROS 2 & Space ROS**](ros2.md) - Interface with the wide ecosystem of robotics tools and libraries
- [**Reinforcement Learning (RL)**](reinforcement_learning.md) - Train and evaluate policies using popular RL algorithms
